// package programs;

/* 
 * Copyright (C) 2007,2008,2009  Anders Nilsson <anders.nilsson@cs.lth.se>
 *
 * This file is part of XMLSchemaCompiler.
 *
 * XMLSchemaCompiler is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * XMLSchemaCompiler is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with XMLSchemaCompiler.  If not, see <http://www.gnu.org/licenses/>.
 */

import AST.Start;
import java.io.File;
import java.io.PrintStream;

public class GenCompiler extends Parser {
    public static void main(String args[]) {

        String dir = "generated";
        String outName = "generated";
        String[] schema = new String[1];
		String grammarName = new String();
        boolean first = true;

        for (int i=0; i<args.length; i++) {
            if (args[i].equals("-d")) {
                dir = args[++i];
				// System.out.println("dir: "+dir);
			} else if (args[i].equals("-g")) {
				grammarName = args[++i];
				dir = grammarName;
				outName = grammarName;
				// System.out.println("grammar: "+grammarName);
			} else if (args[i].equals("-o")) {
				outName = args[++i];
				// System.out.println("outName: "+outName);
			} else {
				// OK, we suppose the remaing arg to be parsed.
				schema[0] = args[i++];
				// System.out.println("schema: "+schema[0]);
			}
		}
		Start ast = parse(schema);

		ast.setGrammar(grammarName);

		ast.registerProblematicNames();

		File siarasDir = new File(dir);
		if (!siarasDir.isDirectory()) {
			siarasDir.mkdir();
		}
		
		String fileName = null;
		String common = dir+File.separator+outName;
		try {
			// Generate JastAdd abstract grammar
			fileName = common+".ast";
			PrintStream pStream = new PrintStream(new File(fileName));
			ast.genAbsGrammar(pStream);

			// Generate JavaCC input
			fileName = common+".jjt";
			pStream = new PrintStream(new File(fileName));
			ast.genJavaCC(pStream);

			// Generate Parser.java
			fileName = dir+"/Parser.java";
			pStream = new PrintStream(new File(fileName));
			ast.genParser(pStream);

			// Generate PrettyPrint.java
			fileName = dir+"/PrettyPrint.java";
			pStream = new PrintStream(new File(fileName));
			ast.genPrettyPrint(pStream);

			// Generate aspects
			fileName = dir+"/GeneratedAspects.jrag";
			pStream = new PrintStream(new File(fileName));
			ast.genAspects(pStream);

		} catch (java.io.FileNotFoundException e) {
			System.out.println("Could not create file: "+fileName);
			e.printStackTrace();
		}
    }

}
